#!/usr/local/bin/python
# -*- coding: iso-8859-1 -*-

## Copyright 2005 by LivingLogic AG, Bayreuth/Germany.
## Copyright 2005 by Walter Drwald
##
## All Rights Reserved
##
## See orasql.py for the license


import sys

from ll import orasql


if __name__ == "__main__":
	import sys, optparse

	p = optparse.OptionParser(usage="usage: %prog [options] connectstring >output.sql")
	fks = ("keep", "disable", "drop")
	p.add_option("-v", "--verbose", dest="verbose", help="Give a progress report?", default=False, action="store_true")
	p.add_option("-f", "--fks", dest="fks", help="How should foreign keys from other schemas be treated (%s)?" % ", ".join(fks), default="disable", choices=fks)
	p.add_option("-x", "--execute", dest="execute", action="store_true", help="immediately execute the commands instead of printing them?")

	(options, args) = p.parse_args()
	if len(args) != 1:
		p.error("incorrect number of arguments")
		sys.exit(1)

	connection = orasql.connect(args[0])
	cursor = connection.cursor()

	codes = []
	for definition in cursor.iterobjects(mode="drop", all=False):
		# Get DDL
		code = ""
		action = "skipped"
		if definition.owner is not None:
			if isinstance(definition, orasql.FKDefinition):
				if options.fks == "disable":
					code = definition.disableddl(cursor)
					action = "disabled"
				elif options.fks == "drop":
					code = definition.dropddl(cursor)
					action = None
		else:
			code = definition.dropddl(cursor)
			action = None

		# Progress report
		if options.verbose:
			msg = "%s: %s: %s %s" % (sys.argv[0], args[0], definition.type, definition.name)
			if definition.owner is not None:
				msg += " (%s)" % definition.owner()
			if action is not None:
				msg += " (%s)" % action
			print >>sys.stderr, msg

		if code.strip():
			# Print or execute DDL
			if options.execute:
				codes.append(code)
			else:
				print "%s;" % code

	# Execute DDL
	if options.execute:
		for code in codes:
			cursor.execute(code)
